function display_orientation_bins(prms)
%
% Display the orientation bins on the unit circle
%   display_orientation_bins(prms)
%
% Input:
%   prms - Parameters [struct]
%          .nbin    - Number of orientation bins   [{8}]
%          .reflect - true  for calculating direction in half-region (0~180)
%                     false for whole-region (0~360)
%
% Output:
%   plot figure
%

%- Base axes -%
plot(cos(2*pi*linspace(0,1,100)),sin(2*pi*linspace(0,1,100)),'k--');hold on;
quiver(0,0,1.4, 0,'LineWidth',3,'color','k','AutoScale','off','MaxHeadSize',0.5); text(1.3, 0.1,'x','FontSize',20)
quiver(0,0,0,-1.4,'LineWidth',3,'color','k','AutoScale','off','MaxHeadSize',0.5); text(0.1,-1.3,'y','FontSize',20);

%- Bin points -%
theta = -2*pi*linspace(0,1,prms.nbin+1);
theta(end) = [];

%- Distinct colors -%
COL = hsv(prms.nbin);
cCOL= circshift(COL,floor(prms.nbin/2))*0.9;

%- Plotting -%
for i = 1:prms.nbin
	plot(cos(theta(i)),sin(theta(i)),'o','markersize',20,'markerfacecolor',COL(i,:),'markeredgecolor','k','linewidth',2);
	text(cos(theta(i)),sin(theta(i)),num2str(i),'color',cCOL(i,:),'fontsize',15,'HorizontalAlignment','center','FontWeight','bold');
end
axis equal;
axis off;
