function test

setup;

%- Input image -%
img = rand(128,64);

%- Spatial gradients -%
G(:,:,1) = imfilter(img,[-1,0;0,1]/2,'replicate');
G(:,:,2) = imfilter(img,[0,-1;1,0]/2,'replicate');

%%-- Feature Extraction --%%
%- GLAC -%
prms = struct('rvecs',1,'nbin',9,'reflect',false);
[fvec prms] = glac(G, prms);

%- GLAC on grids -%
prms_on_grid = struct('rvecs',1,'nbin',9,'reflect',false,'nsbins',[3,4]);
[fvec_on_grid prms_on_grid] = glac_on_grid(G, prms_on_grid);

%%-- Visualization --%%
%- Show the orientation bins -%
figure('name','Orientation bins for glac');
display_orientation_bins(prms);

figure('name','Orientation bins for glac_on_grid');
display_orientation_bins(prms_on_grid);

%- Show the features -%
figure('name','glac features');
ford_ind = feature_order_index(prms);
display_feat(fvec(ford_ind==0),fvec(ford_ind==1),prms,[0.1,0.5,0.8,0.5]);
text(prms.nbin*(0.5:1:size(prms.rvecs,1)),zeros(size(prms.rvecs,1),1),num2str(prms.rvecs),'FontSize',8,'HorizontalAlignment','center'); 
text(prms.nbin*size(prms.rvecs,1),0,'=(\Delta_x \Delta_y)');

figure('name','glac_on_grid features');
[ford_ind_on_grid, grid_ind] = feature_order_index(prms_on_grid);
waxis = 0.9/prms_on_grid.nsbins(1);
haxis = 0.9/prms_on_grid.nsbins(2);
for x = 1:prms_on_grid.nsbins(1)
	for y = 1:prms_on_grid.nsbins(2)
		posind = sub2ind(fliplr(prms_on_grid.nsbins),y,x);
		pos = (grid_ind == posind);
		display_feat(fvec_on_grid(ford_ind_on_grid==0&pos),fvec_on_grid(ford_ind_on_grid==1&pos),prms_on_grid,...
			[0.05+waxis*(x-1),0.05+haxis*(prms_on_grid.nsbins(2)-y),waxis*0.9,haxis*0.9]);
		text(0, prms_on_grid.nbin+1, sprintf('At (%d,%d) spatial bin',x,y),'VerticalAlignment','top');
	end
end


%%---- Utility function ----%%
function display_feat(feat0th, feat1st, prms, pos)
	nr = size(prms.rvecs,1);
	width_per_bin = min(pos(4)/prms.nbin, pos(3)/(prms.nbin*nr+3));
	axes('position',[pos(1),pos(2),width_per_bin,width_per_bin*prms.nbin]);
	imagesc(feat0th);                      title('0th order'); axis off;
	axes('position',[pos(1)+width_per_bin*3,pos(2),width_per_bin*prms.nbin*nr,width_per_bin*prms.nbin]);
	imagesc(reshape(feat1st,prms.nbin,[]));title('1st order'); axis off;
	line(0.5+prms.nbin*ones(2,1)*[1:nr],repmat([-1;prms.nbin+1],1,nr),'color',[0.8,0.8,0.8],'linewidth',2);
